﻿using System.Collections;

namespace TestProject;

/// <summary>
/// 구조적 확장
/// </summary>
public static class StructuralExtension
{
    //////////////////////////////////////////////////////////////////////////////////////////////////// Method
    ////////////////////////////////////////////////////////////////////////////////////////// Static
    //////////////////////////////////////////////////////////////////////////////// Public

    #region 구조적 동일 여부 구하기 - StructuralEquals<T>(source, target)

    /// <summary>
    /// 구조적 동일 여부 구하기
    /// </summary>
    /// <typeparam name="T">객체 타입</typeparam>
    /// <param name="source">소스 객체</param>
    /// <param name="target">타겟 객체</param>
    /// <returns>구조적 동일 여부</returns>
    public static bool StructuralEquals<T>(this T source, T target) where T : IStructuralEquatable
    {
        return source.Equals(target, StructuralComparisons.StructuralEqualityComparer);
    }

    #endregion
    #region 구조적 비교하기 - StructuralCompare<T>(source, target)

    /// <summary>
    /// 구조적 비교하기
    /// </summary>
    /// <typeparam name="T">객체 타입</typeparam>
    /// <param name="source">소스 객체</param>
    /// <param name="target">타겟 객체</param>
    /// <returns>구조적 비교 결과</returns>
    public static int StructuralCompare<T>(this T source, T target) where T : IStructuralComparable
    {
        return source.CompareTo(target, StructuralComparisons.StructuralComparer);
    }

    #endregion
}